/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.intelliform;

import static de.ozgcloud.eingang.intelliform.AttachmentTestFactory.*;

import java.time.Instant;
import java.time.ZonedDateTime;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;

import de.ozgcloud.common.test.TestUtils;

public class DepositDataTestFactory {

	static final String TIMESTAMP_STRING = "2024-12-03T07:49:46.969+01:00";
	public static final XMLGregorianCalendar TIMESTAMP = DatatypeFactory.newDefaultInstance().newXMLGregorianCalendar(TIMESTAMP_STRING);
	public static final ZonedDateTime TIMESTAMP_DATETIME = ZonedDateTime.parse(TIMESTAMP_STRING);
	public static final String CUSTOMPARA_KEY = "param_key";
	public static final String CUTOMPARA_VALUE = "param_value";
	private static final Entry CUSTOMPARA_ENTRY;

	static {
		var entry = new Entry();
		entry.setKey(CUSTOMPARA_KEY);
		entry.setValue(CUTOMPARA_VALUE);
		CUSTOMPARA_ENTRY = entry;
	}

	public static final List<Attachment> ATTACHMENTS = List.of(
			AttachmentTestFactory.createXmlDaten(),
			AttachmentTestFactory.createPdf(),
			AttachmentTestFactory.createPng());

	public static final List<Attachment> MANY_ATTACHMENTS = createManyAttachments(
			TestUtils.loadTextFile("intelliform/XML-Daten-complex.template.xml"),
			Map.of(
					"oeid", ORGANISATIONSEINHEITEN_ID,
					"uuid", UUID.randomUUID().toString(),
					"transactionId", UUID.randomUUID().toString(),
					"now", Instant.now().toString(),
					"antragsteller_anrede", ANTRAGSTELLER_ANREDE,
					"anrede_code", ANTRAGSTELLER_ANREDE_CODE,
					"antragsteller_nachname", ANTRAGSTELLER_NACHNAME,
					"antragsteller_vorname", "Max",
					"antragsteller_email", "max.mustermann@example.com"),
			DOCX1_ATTACHMENT_ID, "Document1.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx1",
			PDF_ATTACHMENT_ID, "Document2.pdf", PDF_ATTACHMENT_CONTENT_TYPE, PDF_ATTACHMENT_CONTENT, "fileid-pdf1",
			DOCX2_ATTACHMENT_ID, "Document3.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx2",
			DOCX3_ATTACHMENT_ID, "Document4.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx3",
			DOCX4_ATTACHMENT_ID, "Document5.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx4",
			DOCX5_ATTACHMENT_ID, "Document6.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx5",
			DOCX6_ATTACHMENT_ID, "Document7.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx6",
			DOCX7_ATTACHMENT_ID, "Document8.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx7",
			DOCX8_ATTACHMENT_ID, "Document9.docx", DOCX_ATTACHMENT_CONTENT_TYPE, DOCX_ATTACHMENT_CONTENT, "fileid-docx8",
			PDF2_ATTACHMENT_ID, "Document9.pdf", PDF_ATTACHMENT_CONTENT_TYPE, PDF_ATTACHMENT_CONTENT, "fileid-pdf2",
			ODT_ATTACHMENT_ID, "Document10.odt", ODT_ATTACHMENT_CONTENT_TYPE, "TestContent5", "fileid-odt1",
			JPG_ATTACHMENT_ID, "Document11.jpg", "image/jpeg", "TestContent6", "fileid-jpg1",
			PNG_ATTACHMENT_ID, "Document12.png", "image/png", "TestContent7", "fileid-png1");

	public static DepositData create() {
		return create(ATTACHMENTS);
	}

	public static DepositData create(Collection<Attachment> attachments) {
		var depositData = new DepositData();
		depositData.setTimestamp(TIMESTAMP);
		depositData.getCustomParameters().add(CUSTOMPARA_ENTRY);
		depositData.setPrimaryDataAttachmentId(AttachmentTestFactory.XML_ATTACHMENT_ID);
		depositData.getAttachments().addAll(attachments);
		return depositData;
	}
}
